# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.7](https://github.com/agntcy/agp/compare/agp-config-v0.1.6...agp-config-v0.1.7) - 2025-04-24

### Added

- improve configuration handling for tracing ([#186](https://github.com/agntcy/agp/pull/186))
- *(data-plane)* support for multiple servers ([#173](https://github.com/agntcy/agp/pull/173))

### Fixed

- *(data-plane)* make new linter version happy ([#184](https://github.com/agntcy/agp/pull/184))

### Other

- declare all dependencies in workspace Cargo.toml ([#187](https://github.com/agntcy/agp/pull/187))
- *(data-plane)* tonic 0.12.3 -> 0.13 ([#170](https://github.com/agntcy/agp/pull/170))
- upgrade to rust edition 2024 and toolchain 1.86.0 ([#164](https://github.com/agntcy/agp/pull/164))

## [0.1.6](https://github.com/agntcy/agp/compare/agp-config-v0.1.5...agp-config-v0.1.6) - 2025-04-08

### Other

- update copyright ([#109](https://github.com/agntcy/agp/pull/109))

## [0.1.5](https://github.com/agntcy/agp/compare/agp-config-v0.1.4...agp-config-v0.1.5) - 2025-03-18

### Added

- propagate context to enable distributed tracing ([#90](https://github.com/agntcy/agp/pull/90))

## [0.1.4](https://github.com/agntcy/agp/compare/agp-config-v0.1.3...agp-config-v0.1.4) - 2025-03-11

### Other

- *(agp-config)* release v0.1.3 ([#75](https://github.com/agntcy/agp/pull/75))

## [0.1.3](https://github.com/agntcy/agp/compare/agp-config-v0.1.2...agp-config-v0.1.3) - 2025-03-07

### Other

- Windows Instructions ([#73](https://github.com/agntcy/agp/pull/73))

## [0.1.2](https://github.com/agntcy/agp/compare/agp-config-v0.1.1...agp-config-v0.1.2) - 2025-02-28

### Added

- add message handling metrics

## [0.1.1](https://github.com/agntcy/agp/compare/agp-config-v0.1.0...agp-config-v0.1.1) - 2025-02-14

### Other

- updated the following local packages: agp-tracing

## [0.1.0](https://github.com/agntcy/agp/releases/tag/agp-config-v0.1.0) - 2025-02-10

### Other

- reduce the number of crates to publish (#10)
